---
delivery_guarantee: "best_effort"
description: "The Vector `docker` source ingests data through the docker engine daemon and outputs `log` events."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+docker%22
operating_systems: ["linux","macos","windows"]
sidebar_label: "docker|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sources/docker.rs
status: "beta"
title: "Docker Source"
unsupported_operating_systems: []
---

The Vector `docker` source ingests data through the docker engine daemon and outputs [`log`][docs.data-model.log] events.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sources/docker.md.erb
-->

## Configuration

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sources.my_source_id]
  # REQUIRED
  type = "docker" # must be: "docker"

  # OPTIONAL
  include_containers = ["my_container_name", "container_prefix", "9b6247364a03"] # example, no default
  include_images = ["my_image_name", "httpd", "redis"] # example, no default
  include_labels = ["label_key1=label_value1", "label_key2=label_value2"] # example, no default
```

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["my_container_name","container_prefix","9b6247364a03"]]}
  name={"include_containers"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  >

### include_containers

A list of container IDs _or_ names to match against. Prefix matches are supported, meaning you can supply just the first few characters of the
container ID or name. If not provided, all containers will be included.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["my_image_name","httpd","redis"]]}
  name={"include_images"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  >

### include_images

A list of image names to match against. If not provided, all images will be included.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["label_key1=label_value1","label_key2=label_value2"]]}
  name={"include_labels"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  >

### include_labels

A list of container object labels to match against when filtering running containers. This should follow the described label&#39;s synatx in [docker object labels docs][urls.docker_object_labels].


</Field>


</Fields>

## Env Vars

<Fields filters={true}>


<Field
  common={true}
  defaultValue={"unix:///var/run/docker.sock"}
  enumValues={null}
  examples={["unix://path/to/socket","tcp://host:2375/path"]}
  name={"DOCKER_HOST"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### DOCKER_HOST

The docker host to connect to. See [Connecting to the Docker daemon](#connecting-to-the-docker-daemon) for more info.


</Field>


<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  name={"DOCKER_VERIFY_TLS"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"bool"}
  unit={null}
  >

### DOCKER_VERIFY_TLS

If `true` (the default), Vector will validate the TLS certificate of the remote host. Do NOT set this to `false` unless you understand the risks of not verifying the remote certificate. See [Connecting to the Docker daemon](#connecting-to-the-docker-daemon) for more info.


</Field>


</Fields>

## Output

The `docker` source ingests data through the docker engine daemon and outputs [`log`][docs.data-model.log] events.
For example:

```javascript
{
  "com.example.vendor": "Timber Inc.",
  "container_created_at": "2019-11-01T21:15:47+00:00",
  "container_id": "9b6247364a03",
  "container_name": "evil_ptolemy",
  "image": "ubuntu:latest",
  "message": "Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100",
  "stream": "stdout",
  "timestamp": "2019-11-01T21:15:47+00:00"
}
```
More detail on the output schema is below.

<Fields filters={true}>


<Field
  defaultValue={null}
  enumValues={null}
  examples={[{"com.example.vendor":"Timber Inc."},{"com.example.name":"Vector"},{"com.example.build-date":"2029-04-12T23:20:50.52Z"}]}
  name={"`[label-key]`"}
  path={null}
  required={true}
  type={"string"}
  >

### `[label-key]`

[Docker object labels][urls.docker_object_labels]. Each label is inserted with it's exact key/value pair.


</Field>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47+00:00"]}
  name={"container_created_at"}
  path={null}
  required={true}
  type={"timestamp"}
  >

### container_created_at

A UTC timestamp representing when the container was created.


</Field>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["9b6247364a03","715ebfcee040"]}
  name={"container_id"}
  path={null}
  required={true}
  type={"string"}
  >

### container_id

The Docker container ID that the log was collected from.


</Field>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["evil_ptolemy","nostalgic_stallman"]}
  name={"container_name"}
  path={null}
  required={true}
  type={"string"}
  >

### container_name

The Docker container name that the log was collected from.


</Field>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["ubuntu:latest","busybox","timberio/vector:latest-alpine"]}
  name={"image"}
  path={null}
  required={true}
  type={"string"}
  >

### image

The image name that the container is based on.


</Field>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100"]}
  name={"message"}
  path={null}
  required={true}
  type={"string"}
  >

### message

The raw log message, unaltered.


</Field>


<Field
  defaultValue={null}
  enumValues={["stdout","stderr"]}
  examples={["stdout","stderr"]}
  name={"stream"}
  path={null}
  required={true}
  type={"string"}
  >

### stream

The [standard stream][urls.standard_streams] that the log was collected from.


</Field>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47+00:00"]}
  name={"timestamp"}
  path={null}
  required={true}
  type={"timestamp"}
  >

### timestamp

The UTC timestamp extracted from the Docker log event.


</Field>


</Fields>

## How It Works

### Connecting to the Docker daemon

Vector will automatically attempt to connect to the docker daemon for you. In most
situations if your current user is able to run `docker ps` then Vector will be able to
connect. Vector will also respect if `DOCKER_HOST` and `DOCKER_VERIFY_TLS` are set. Vector will also
use the other default docker environment variables if they are set. See the [Docker daemon docs][urls.docker_daemon].

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[urls.docker_daemon]: https://docs.docker.com/engine/reference/commandline/dockerd/#daemon-socket-option
[urls.docker_object_labels]: https://docs.docker.com/config/labels-custom-metadata/
[urls.standard_streams]: https://en.wikipedia.org/wiki/Standard_streams
