---
title: Unit Tests
description: Vector's unit test configuration options, allowing you to unit test your Vector configuration files.
status: beta
---

It's possible to define unit tests within a Vector configuration file that cover
a network of transforms within the topology. The intention of these tests is to
improve the maintainability of configs containing larger and more complex
combinations of transforms.

Executing tests within a config file can be done with the `test` subcommand:

```bash
vector test /etc/vector/*.toml
```

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/tests.md.erb
-->

## Configuration

import Tabs from '@theme/Tabs';

<Tabs
  block={true}
  defaultValue="common"
  values={[
    { label: 'Common', value: 'common', },
    { label: 'Advanced', value: 'advanced', },
  ]
}>

import TabItem from '@theme/TabItem';

<TabItem value="common">

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" />

```toml
[transforms.bar]
  type = "regex_parser"
  regex = "^(?P<timestamp>[\\w\\-:\\+]+) (?P<level>\\w+) (?P<message>.*)$"

[[tests]]
  # REQUIRED - General
  name = "foo test" # example

  # REQUIRED - Outputs
  [[tests.outputs]]
    # REQUIRED - General
    extract_from = "foo" # example

    # REQUIRED - Conditions
    [[tests.outputs.conditions]]
      # REQUIRED
      type = "check_fields" # example

      # OPTIONAL
      "message.eq" = "this is the content to match against"
      "host.exists" = true
      "method.neq" = "POST"

  # REQUIRED - Input
  [tests.input]
    # REQUIRED
    type = "raw" # example, enum
    insert_at = "foo" # example

    # OPTIONAL
    value = "some message contents" # example, no default, relevant when type = "raw"
```

</TabItem>
<TabItem value="advanced">

<CodeHeader fileName="vector.toml" />

```toml
[transforms.bar]
  type = "regex_parser"
  regex = "^(?P<timestamp>[\\w\\-:\\+]+) (?P<level>\\w+) (?P<message>.*)$"

[[tests]]
  # REQUIRED - General
  name = "foo test" # example

  # REQUIRED - Outputs
  [[tests.outputs]]
    # REQUIRED - General
    extract_from = "foo" # example

    # REQUIRED - Conditions
    [[tests.outputs.conditions]]
      # REQUIRED
      type = "check_fields" # example

      # OPTIONAL
      "message.eq" = "this is the content to match against"
      "host.exists" = true
      "method.neq" = "POST"

  # REQUIRED - Input
  [tests.input]
    # REQUIRED - General
    type = "raw" # example, enum
    insert_at = "foo" # example

    # OPTIONAL - General
    value = "some message contents" # example, no default, relevant when type = "raw"

    # OPTIONAL - Log fields
    [tests.input.log_fields]
      message = "some message contents" # example
      host = "myhost" # example

    # OPTIONAL - Metric
    [tests.input.metric]
      # REQUIRED - General
      type = "counter" # example, enum
      name = "duration_total" # example
      timestamp = "2019-11-01T21:15:47.443232Z" # example
      val = 10.2 # example

      # OPTIONAL - General
      direction = "plus" # example, no default, enum
      sample_rate = 1 # example, no default

      # OPTIONAL - Tags
      [tests.input.metric.tags]
        host = "foohost" # example
        region = "us-east-1" # example
```

</TabItem>

</Tabs>

For more information about unit tests check out [this guide][docs.setup.guides.unit-testing].

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  name={"input"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"table"}
  unit={null}
  >

### input

A table that defines a unit test input event.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["foo"]}
  name={"insert_at"}
  path={"input"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### insert_at

The name of a transform, the input event will be delivered to this transform in order to begin the test.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  name={"log_fields"}
  path={"input"}
  relevantWhen={{"type":"log"}}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

#### log_fields

Specifies the log fields when the input type is &#39;log&#39;.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"message":"some message contents"},{"host":"myhost"}]}
  name={"`[field-name]`"}
  path={"input.log_fields"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"*"}
  unit={null}
  >

##### `[field-name]`

A key/value pair representing a field to be added to the input event.


</Field>


</Fields>

</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  name={"metric"}
  path={"input"}
  relevantWhen={{"type":"metric"}}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

#### metric

Specifies the metric type when the input type is &#39;metric&#39;.

<Fields filters={false}>


<Field
  common={false}
  defaultValue={null}
  enumValues={{"plus":"Increase the gauge","minus":"Decrease the gauge"}}
  examples={["plus","minus"]}
  name={"direction"}
  path={"input.metric"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

##### direction

The direction to increase or decrease the gauge value.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["duration_total"]}
  name={"name"}
  path={"input.metric"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

##### name

The name of the metric. Defaults to `&lt;field&gt;_total` for `counter` and `&lt;field&gt;` for `gauge`.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[1]}
  name={"sample_rate"}
  path={"input.metric"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"float"}
  unit={null}
  >

##### sample_rate

The bucket/distribution the metric is a part of.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  name={"tags"}
  path={"input.metric"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

##### tags

Key/value pairs representing [metric tags][docs.data-model.metric#tags].

<Fields filters={false}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"host":"foohost"},{"region":"us-east-1"}]}
  name={"`[tag-name]`"}
  path={"input.metric.tags"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

###### `[tag-name]`

Key/value pairs representing [metric tags][docs.data-model.metric#tags].


</Field>


</Fields>

</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47.443232Z"]}
  name={"timestamp"}
  path={"input.metric"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

##### timestamp

Time metric was created/ingested.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={{"counter":"A [counter metric type][docs.data-model.metric#counter].","gauge":"A [gauge metric type][docs.data-model.metric#gauge].","histogram":"A [distribution metric type][docs.data-model.metric#distribution].","set":"A [set metric type][docs.data-model.metric#set]."}}
  examples={["counter"]}
  name={"type"}
  path={"input.metric"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

##### type

The metric type.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[10.2]}
  name={"val"}
  path={"input.metric"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"float"}
  unit={null}
  >

##### val

Amount to increment/decrement or gauge.


</Field>


</Fields>

</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={{"raw":"Creates a log event where the message contents are specified in the field 'value'.","log":"Creates a log event where log fields are specified in the table 'log_fields'.","metric":"Creates a metric event, where its type and fields are specified in the table 'metric'."}}
  examples={["raw","log","metric"]}
  name={"type"}
  path={"input"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### type

The event type.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["some message contents"]}
  name={"value"}
  path={"input"}
  relevantWhen={{"type":"raw"}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### value

Specifies the log message field contents when the input type is &#39;raw&#39;.


</Field>


</Fields>

</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["foo test"]}
  name={"name"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### name

A unique identifier for this test.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  name={"outputs"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"[table]"}
  unit={null}
  >

### outputs

A table that defines a unit test expected output.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  name={"conditions"}
  path={"outputs"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"[table]"}
  unit={null}
  >

#### conditions

A table that defines a collection of conditions to check against the output of a transform. A test is considered to have passed when each condition has resolved true for one or more events extracted from the target transform.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"message.eq":"this is the content to match against"}]}
  name={"`<field_name>`.eq"}
  path={"outputs.conditions"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

##### `<field_name>`.eq

Check whether a fields contents exactly matches the value specified.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"host.exists":true}]}
  name={"`<field_name>`.exists"}
  path={"outputs.conditions"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  >

##### `<field_name>`.exists

Check whether a field exists or does not exist, depending on the provided valuebeing `true` or `false` respectively.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"method.neq":"POST"}]}
  name={"`<field_name>`.neq"}
  path={"outputs.conditions"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

##### `<field_name>`.neq

Check whether a fields contents does not match the value specified.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["check_fields"]}
  name={"type"}
  path={"outputs.conditions"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

##### type

The type of the condition to execute. Currently only the `check_fields` type is available.


</Field>


</Fields>

</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["foo"]}
  name={"extract_from"}
  path={"outputs"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### extract_from

The name of a transform, at the end of the test events extracted from this transform will be checked against a table of conditions.


</Field>


</Fields>

</Field>


</Fields>


[docs.data-model.metric#counter]: /docs/about/data-model/metric/#counter
[docs.data-model.metric#distribution]: /docs/about/data-model/metric/#distribution
[docs.data-model.metric#gauge]: /docs/about/data-model/metric/#gauge
[docs.data-model.metric#set]: /docs/about/data-model/metric/#set
[docs.data-model.metric#tags]: /docs/about/data-model/metric/#tags
[docs.setup.guides.unit-testing]: /docs/setup/guides/unit-testing/
